

set -ex



test -f $PREFIX/include/arrow/api.h
test -f $PREFIX/include/arrow/flight/types.h
test -f $PREFIX/include/plasma/client.h
test -f $PREFIX/include/parquet/api/reader.h
test -f $PREFIX/lib/libarrow.dylib
test -f $PREFIX/lib/libarrow_python.dylib
test -f $PREFIX/lib/libparquet.dylib
test -f $PREFIX/lib/libplasma.dylib
test ! -f $PREFIX/lib/libarrow.a
test ! -f $PREFIX/lib/libarrow_flight.a
test ! -f $PREFIX/lib/libarrow_python.a
test ! -f $PREFIX/lib/libplasma.a
test ! -f $PREFIX/lib/libparquet.a
conda inspect linkages -p $PREFIX $PKG_NAME
conda inspect objects -p $PREFIX $PKG_NAME
exit 0
